@@ -6,10 +6,7 @@ Created on June 23 2020
 """
 
 
-from os.path import dirname
+from .version import __version__
 from .Parser import Parser, build_args_parser
 
 __all__ = ["Parser", "build_args_parser"]
-
-with open(dirname(__file__) + '/../RELEASE.md', 'r') as f:
-    __version__ = f.readline().split()[0]
